@@ -1,5 +1,5 @@
 package List::Objects::WithUtils;
-$List::Objects::WithUtils::VERSION = '2.021003';
+$List::Objects::WithUtils::VERSION = '2.022001';
 use Carp;
 use strictures 2;
 
@@ -284,17 +284,23 @@ nicely with typed or untyped list objects:
 
   package Accounts;
   use List::Objects::Types -types;
-  use Moo; use MooX::late;
+  use Moo 2;
 
   has usergroups => (
     is        => 'ro',
-    # +{ group => [ [ $usr => $id ], ... ] }
+    # +{ $group => [ [ $usr => $id ], ... ] }
     # Coerced to objects all the way down:
     isa       => TypedHash[ TypedArray[ArrayObj] ],
     coerce    => 1,
     builder   => sub { +{} },
   );
 
+  # ... later ...
+  my $users_in_grp = $accts->usergroups
+    ->get($some_group)
+    ->grep(sub { $_[0]->get(0) });
+    
+
 =head2 Objects
 
 =head3 Arrays
@@ -476,9 +482,6 @@ L<List::UtilsBy>
 L<Type::Tiny>
 
 Inspiration for a few pieces comes from the "classic" (version 0.33)
-L<List::MoreUtils>. MoreUtils was dropped from the required dependency chain
-in Lowu-2.10 and will be reevaluated later. Users with 0.3x versions of
-L<List::MoreUtils> will see a significant performance boost in performing
-certain array operations.
+L<List::MoreUtils>. 
 
 =cut
