@@ -1,5 +1,5 @@
 package List::Objects::WithUtils::Role::Array;
-$List::Objects::WithUtils::Role::Array::VERSION = '2.021003';
+$List::Objects::WithUtils::Role::Array::VERSION = '2.022001';
 use strictures 2;
 
 use Carp            ();
@@ -23,11 +23,6 @@ our $UsingUtilsByXS = 0;
   }
 }
 
-use constant USING_LIST_MOREUTILS => !! eval {;
-  require List::MoreUtils;
-  (List::MoreUtils->VERSION || '') =~ /^0.3/
-};
-
 =pod
 
 =for Pod::Coverage ARRAY_TYPE blessed_or_pkg
@@ -308,10 +303,11 @@ sub grep {
 
 { no warnings 'once'; *indices = *indexes; }
 sub indexes {
-  blessed_or_pkg($_[0])->new(
-    USING_LIST_MOREUTILS ? &List::MoreUtils::indexes( $_[1], @{ $_[0] } )
-      : grep {; local *_ = \$_[0]->[$_]; $_[1]->() } 0 .. $#{ $_[0] }
-  )
+  $_[1] ? 
+    blessed_or_pkg($_[0])->new(
+      grep {; local *_ = \$_[0]->[$_]; $_[1]->() } 0 .. $#{ $_[0] }
+    )
+    : blessed_or_pkg($_[0])->new( 0 .. $#{ $_[0] } )
 }
 
 sub sort {
@@ -325,7 +321,7 @@ sub sort {
       } @{ $_[0] }
     )
   }
-  return blessed_or_pkg($_[0])->new( CORE::sort @{ $_[0] } )
+  blessed_or_pkg($_[0])->new( CORE::sort @{ $_[0] } )
 }
 
 sub reverse {
@@ -367,9 +363,6 @@ sub first_where { &List::Util::first( $_[1], @{ $_[0] } ) }
 
 sub last_where {
   my ($self, $cb) = @_;
-
-  return &List::MoreUtils::lastval($cb, @$self) if USING_LIST_MOREUTILS;
-
   my $i = @$self;
   while ($i--) {
     local *_ = \$self->[$i];
@@ -386,9 +379,6 @@ sub last_where {
 }
 sub firstidx { 
   my ($self, $cb) = @_;
-
-  return &List::MoreUtils::firstidx($cb, @$self) if USING_LIST_MOREUTILS;
-
   for my $i (0 .. $#$self) {
     local *_ = \$self->[$i];
     return $i if $cb->();
@@ -398,9 +388,6 @@ sub firstidx {
 
 sub lastidx {
   my ($self, $cb) = @_;
-
-  return &List::MoreUtils::lastidx($cb, @$self) if USING_LIST_MOREUTILS;
-
   for my $i (CORE::reverse 0 .. $#$self) {
     local *_ = \$self->[$i];
     return $i if $cb->(); 
@@ -574,26 +561,22 @@ sub items_after {
 sub items_after_incl {
   my $started;
   blessed_or_pkg($_[0])->new(
-    USING_LIST_MOREUTILS ? &List::MoreUtils::after_incl($_[1], @{ $_[0] })
-      : CORE::grep $started ||= $_[1]->(), @{ $_[0] }
+    CORE::grep $started ||= $_[1]->(), @{ $_[0] }
   )
 }
 
 sub items_before {
   my $more = 1;
   blessed_or_pkg($_[0])->new(
-    USING_LIST_MOREUTILS ? &List::MoreUtils::before($_[1], @{ $_[0] })
-      : CORE::grep $more &&= !$_[1]->(), @{ $_[0] }
+    CORE::grep $more &&= !$_[1]->(), @{ $_[0] }
   )
 }
 
 sub items_before_incl {
   my $more = 1; my $lag = 1;
   blessed_or_pkg($_[0])->new(
-    USING_LIST_MOREUTILS ? &List::MoreUtils::before_incl($_[1], @{ $_[0] })
-      : CORE::grep $more &&= do {
-          my $x = $lag; $lag = !$_[1]->(); $x
-      }, @{ $_[0] }
+    CORE::grep $more &&= do { my $x = $lag; $lag = !$_[1]->(); $x }, 
+      @{ $_[0] }
   )
 }
 
@@ -605,10 +588,7 @@ sub shuffle {
 
 sub uniq {
   my %s;
-  blessed_or_pkg($_[0])->new(
-    USING_LIST_MOREUTILS ? &List::MoreUtils::uniq(@{ $_[0] })
-      : grep {; not $s{$_}++ } @{ $_[0] }
-  )
+  blessed_or_pkg($_[0])->new( CORE::grep {; not $s{$_}++ } @{ $_[0] } )
 }
 
 sub sort_by {
@@ -887,7 +867,7 @@ Returns all elements in the array as a plain list.
 
 Like L</part>, but creates an array-type object containing two
 partitions; the first contains all items for which the subroutine evaluates to
-true, the second contains the remaining items.
+true, the second contains items for which the subroutine evaluates to false.
 
 =head3 nsect
 
@@ -1135,8 +1115,13 @@ on; you can also use the topicalizer C<$_>.
 
   my $matched = $array->indexes(sub { /foo/ });
 
-Like L</grep>, but returns a new array object consisting of the list of
-B<indexes> for which the given subroutine evaluates to true.
+If passed a reference to a subroutine, C<indexes> behaves like L</grep>, but
+returns a new array object consisting of the list of array indexes for which
+the given subroutine evaluates to true.
+
+If no subroutine is provided, returns a new array object consisting of the
+full list of indexes (like C<keys> on an array in perl-5.12+). This feature
+was added in C<v2.022>.
 
 =head3 first_where
 
@@ -1295,7 +1280,7 @@ Reduces the array by calling the given subroutine for each element of the
 list. C<$a> is the accumulated value; C<$b> is the current element. See
 L<List::Util/"reduce">.
 
-Prior to v2.18.1, C<$_[0]> and C<$_[1]> must be used in place of C<$a> and
+Prior to C<v2.18.1>, C<$_[0]> and C<$_[1]> must be used in place of C<$a> and
 C<$b>, respectively. Using positional arguments may make for cleaner syntax in
 some cases:
 
